@@ -153,12 +153,15 @@ if __name__ == '__main__':
     vals1['items'] = itemstr
     vals1['price'] = "{:.2f}".format(itemsum).replace(".", ",")
 
-    cacheDir = os.path.expanduser("~\\Documents\\InvoiceGen\\cache\\")
+    cacheDir = os.path.expanduser("~\\Documents\\InvoiceGen\\cache")
     invoiceDir = os.path.expanduser("~\\Documents\\InvoiceGen\\Invoices")
 
     if not os.path.exists(invoiceDir):
         os.makedirs(invoiceDir)
 
+    if not os.path.exists(cacheDir):
+        os.makedirs(cacheDir)
+
     filename = "Lasku" + vals1.get('invoiceid')
 
     with open(sys.prefix+"\\res\\template.tex", "r", encoding="utf-8") as template:
@@ -170,8 +173,8 @@ if __name__ == '__main__':
         with open(cacheDir+filename + ".tex", "w", encoding="utf-8") as output:
             output.write(text)
 
-    os.system("pdflatex -output-directory=" +cacheDir + filename + ".tex")
-    os.system("move " + cacheDir+filename + ".pdf " + invoiceDir)
+    os.system("pdflatex -output-directory=" +cacheDir +"\\"+ filename + ".tex")
+    os.system("move " + cacheDir+"\\"+filename + ".pdf " + invoiceDir)
     win1.close()
 
 
